*** Comments ***
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License


*** Settings ***
Documentation   [BASIC-36] Instantiation Parameter

Library   OperatingSystem
Library   String
Library   Collections
Library   RequestsLibrary
Library   yaml
Library   JsonValidator
Library   JSONLibrary
Library   SeleniumLibrary
Library   ../lib/renderConfig.py

Resource   %{ROBOT_DEVOPS_FOLDER}/lib/rest_lib.resource
Resource   %{ROBOT_DEVOPS_FOLDER}/lib/vnfd_lib.resource
Resource   %{ROBOT_DEVOPS_FOLDER}/lib/ns_lib.resource
Resource   %{ROBOT_DEVOPS_FOLDER}/lib/nsd_lib.resource
Resource   %{ROBOT_DEVOPS_FOLDER}/lib/vnf_lib.resource
Resource   %{ROBOT_DEVOPS_FOLDER}/lib/openstack_lib.resource

Test Tags   basic_36   cluster_kpi   sanity   regression

Suite Setup   Run Keyword And Ignore Error   Suite Preparation


*** Variables ***
# Descriptor details to be used
${VNFD_PKG}   hackfest_basic_vnf
${VNFD_NAME}   hackfest_basic-vnf
${VDU_NAME}   hackfest_basic-VM
${VNF_INDEX}   vnf
${NSD_PKG}   hackfest_basic_ns
${NSD_NAME}   hackfest_basic-ns
${NS_INSTANCE_NAME}   Demo_instantiationparameter
${NEW_INSTANCE_NAME}   Test_Instantiationparameter
${VIMACCOUNT_NAME}   nsconfig

# NS instance name and configuration
${NS_NAME}   Instan_Parameter
${CONFIG_FILE}   instantiation_parameter.yaml

# SSH keys and username to be used
${PUBLICKEY}   %{HOME}/.ssh/id_rsa.pub
${PRIVATEKEY}   %{HOME}/.ssh/id_rsa
${USERNAME}   test
${PASSWORD}   test


*** Test Cases ***
Create VNFD Descriptor Packages
    [Documentation]   Upload VNFD Descriptor
    ${VNFD_ID}=   Create VNFD   %{PACKAGES_FOLDER}/${VNFD_PKG}
    Set Suite Variable   ${VNFD_ID}

Create NSD Descriptor
    [Documentation]   Upload NSD Descriptor
    ${NSD_ID}=   Create NSD   %{PACKAGES_FOLDER}/${NSD_PKG}
    Set Suite Variable   ${NSD_ID}

Render a template
    [Documentation]   Generate from a template the instantiation parameters that will be used for the NS instance.
    ${stdout}=   Render Config   %{RESOURCE_FOLDER}/${CONFIG_FILE}
    Log   ${stdout}
    Set Suite Variable   ${NSTEMPLATECONFIG_FILE}   ${stdout}

Create Ns Config Template
    [Documentation]   Create the ns config template
    ${TEMPLATE_ID}=   Run   osm nsconfig-create ${NS_INSTANCE_NAME} --nsd ${NSD_NAME} --config_file %{RESOURCE_FOLDER}/${CONFIG_FILE}
    Set Suite Variable   ${TEMPLATE_ID}

Get Template ID
    [Documentation]   Test case to get the created template id
    ${TEMP_ID}=   Run   osm nsconfig-list | grep ${NS_INSTANCE__NAME} | awk '{print $4}'
    Log   ${TEMP_ID}
    Set Suite Variable   ${TEMP_ID}

Check Template Name
    [Documentation]   Verify the template name is created successfully.
    ${LIST_TEMPLATE_NAME}=   Run   osm nsconfig-list | grep ${NS_INSTANCE__NAME}
    Log   ${LIST_TEMPLATE_NAME}
    Should Contain   ${LIST_TEMPLATE_NAME}   ${NS_INSTANCE_NAME}

Update NsConfig Template
    [Documentation]   Updating the ns config template name
    ${UPDATED_NSCONFIG_NAME}=   Run   osm nsconfig-update ${NS_INSTANCE__NAME} --newname ${NEW_INSTANCE_NAME} --config_file %{RESOURCE_FOLDER}/${CONFIG_FILE}
    Set Suite Variable   ${UPDATED_NSCONFIG_NAME}

Verify Updated Template Name
    [Documentation]   Test case to verify the updated templated name is updated successfully
    ${UPDATED_NEW_NAME}=   Run   osm nsconfig-list | grep ${NEW_INSTANCE_NAME}
    Log   ${UPDATED_NEW_NAME}
    Should Contain   ${UPDATED_NEW_NAME}   ${NEW_INSTANCE_NAME}

Get Vim Account Id
    [Documentation]   Test case to grep the vim account id from the vim list
    ${VIMACCOUNT_ID}=   Run   osm vim-list | grep ${VIMACCOUNT_NAME} | awk '{print $4}'
    Set Suite Variable   ${VIMACCOUNT_ID}

Create Network Instance
    [Documentation]   Launch a Network Service
    ${ID}=   Run   osm ns-create --ns_name ${NS_NAME} --nsd_name ${NSD_ID} --vim_account ${VIMACCOUNT_ID} --ns_config_template ${NEW_INSTANCE_NAME}
    Log   ${ID}
    Set Suite Variable   ${NS_ID}   ${ID}
    Sleep   60sec

Get NS Id
    [Documentation]   Test case to get the ns instance id
    ${ID}=   Get Ns Id   ${NS_NAME}
    Set Suite Variable   ${NS_ID}   ${ID}

Get Vnf Instance Id
    [Documentation]   Test case to get the vnf instance id
    ${ID}=   Get Ns Vnfr Ids   ${NS_ID}
    Set Suite Variable   ${VNF_ID}   ${ID}

Get NS Instance Name
    [Documentation]   Test case to get the instance name from the launched ns.
    ${INSTANCE_NAME}=   Run   osm ns-show ${NS_ID} --literal | grep instance_name | awk '{print $2}'
    Set Suite Variable   ${INSTANCE_NAME}

Get Server Id
    [Documentation]   Test case to get the server id from the vnf instance
    ${SERVER_ID}=   Run   osm vnf-show ${VNF_ID} --literal | grep vim-id | awk '{print $2}'
    Set Suite Variable   ${SERVER_ID}

Check VM Status
    [Documentation]   Test case to verify the vm status in the openstack
    ${VM_STATUS}=   Run   openstack server show ${SERVER_ID} | grep status | awk '{print $4}'
    Set Test Variable   ${VM_STATUS}
    Should Contain   ${VM_STATUS}   ACTIVE

Get Openstack Instance Name
    [Documentation]   Test case to get the openstack instance name
    ${OPENSTACK_INSTANCE_NAME}=   Run   openstack server list | grep ${SERVER_ID} | awk '{print $4}'
    Set Suite Variable   ${OPENSTACK_INSTANCE_NAME}

Verify Instance Name
    [Documentation]   Test case to verify the instance name are equal
    Should Be Equal   ${INSTANCE_NAME}   ${OPENSTACK_INSTANCE_NAME}

Delete NS Instance
   [Documentation]   Delete the network service
   [Tags]   cleanup
   Delete NS   ${NS_NAME}

Delete NSD
   [Documentation]   Delete the ns descriptor
   [Tags]   cleanup
   Delete NSD   ${NSD_NAME}

Delete VNFD
   [Documentation]   Delete the vnf descriptor
   [Tags]   cleanup
   Delete VNFD   ${VNFD_NAME}

Verify Config Template
   [Documentation]   Test case to verify the config template
   ${LIST_TEMPLATE}=   Run   osm nsconfig-list | grep ${NEW_INSTANCE_NAME}
   Should Not Contain   ${LIST_TEMPLATE}   ${NEW_INSTANCE_NAME}


*** Keywords ***
Suite Cleanup
    [Documentation]   Test Suite Cleanup: Deleting Descriptor, instance

    Run Keyword If Any Tests Failed   Delete NS   ${NS_NAME}

    Run Keyword If Any Tests Failed   Delete NSD   ${NSD_NAME}

    Run Keyword If Any Tests Failed   Delete VNFD   ${VNFD_NAME}
